=encoding utf8

=head1 NAME

Uk::Cyrl - Package for language Uk

=cut

package Locale::CLDR::Locales::Uk::Cyrl;

# This file auto generated
#	on Wed 15 Jan 11:22:39 am GMT

use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use feature 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::Uk');

no Moo;

1;
